
/*******************************************************************************
 * LVGL Widgets
 * This is a widgets demo for LVGL - Light and Versatile Graphics Library
 * import from: https://github.com/lvgl/lv_demos.git
 *
 * Dependent libraries:
 * LVGL: https://github.com/lvgl/lvgl.git

 * Touch libraries:
 * FT6X36: https://github.com/strange-v/FT6X36.git
 * GT911: https://github.com/TAMCTec/gt911-arduino.git
 * XPT2046: https://github.com/PaulStoffregen/XPT2046_Touchscreen.git
 *
 * LVGL Configuration file:
 * Copy your_arduino_path/libraries/lvgl/lv_conf_template.h
 * to your_arduino_path/libraries/lv_conf.h
 * Then find and set:
 * #define LV_COLOR_DEPTH     16
 * #define LV_TICK_CUSTOM     1
 *
 * For SPI display set color swap can be faster, parallel screen don't set!
 * #define LV_COLOR_16_SWAP   1
 *
 * Optional: Show CPU usage and FPS count
 * #define LV_USE_PERF_MONITOR 1
 ******************************************************************************/
 //#define LV_USE_PERF_MONITOR 1

#include <lvgl.h>
#include "ui.h"
//#include "ui_events.h"
//#include "ui_helpers.h"
#include <HardwareSerial.h>

HardwareSerial SerialPort(2); // use UART2
String AIDATA ="##@%%";
// Update these with values suitable for your network.

/*******************************************************************************
 * Start of Arduino_GFX setting
 *
 * Arduino_GFX try to find the settings depends on selected board in Arduino IDE
 * Or you can define the display dev kit not in the board list
 * Defalult pin list for non display dev kit:
 * Arduino Nano, Micro and more: CS:  9, DC:  8, RST:  7, BL:  6, SCK: 13, MOSI: 11, MISO: 12
 * ESP32 various dev board     : CS:  5, DC: 27, RST: 33, BL: 22, SCK: 18, MOSI: 23, MISO: nil
 * ESP32-C3 various dev board  : CS:  7, DC:  2, RST:  1, BL:  3, SCK:  4, MOSI:  6, MISO: nil
 * ESP32-S2 various dev board  : CS: 34, DC: 35, RST: 33, BL: 21, SCK: 36, MOSI: 35, MISO: nil
 * ESP32-S3 various dev board  : CS: 40, DC: 41, RST: 42, BL: 48, SCK: 36, MOSI: 35, MISO: nil
 * ESP8266 various dev board   : CS: 15, DC:  4, RST:  2, BL:  5, SCK: 14, MOSI: 13, MISO: 12
 * Raspberry Pi Pico dev board : CS: 17, DC: 27, RST: 26, BL: 28, SCK: 18, MOSI: 19, MISO: 16
 * RTL8720 BW16 old patch core : CS: 18, DC: 17, RST:  2, BL: 23, SCK: 19, MOSI: 21, MISO: 20
 * RTL8720_BW16 Official core  : CS:  9, DC:  8, RST:  6, BL:  3, SCK: 10, MOSI: 12, MISO: 11
 * RTL8722 dev board           : CS: 18, DC: 17, RST: 22, BL: 23, SCK: 13, MOSI: 11, MISO: 12
 * RTL8722_mini dev board      : CS: 12, DC: 14, RST: 15, BL: 13, SCK: 11, MOSI:  9, MISO: 10
 * Seeeduino XIAO dev board    : CS:  3, DC:  2, RST:  1, BL:  0, SCK:  8, MOSI: 10, MISO:  9
 * Teensy 4.1 dev board        : CS: 39, DC: 41, RST: 40, BL: 22, SCK: 13, MOSI: 11, MISO: 12
 ******************************************************************************/
#include <Arduino_GFX_Library.h>
#define TFT_BL 2
//#define GFX_BL DF_GFX_BL // default backlight pin, you may replace DF_GFX_BL to actual backlight pin

/* More dev device declaration: https://github.com/moononournation/Arduino_GFX/wiki/Dev-Device-Declaration */
#if defined(DISPLAY_DEV_KIT)
Arduino_GFX *gfx = create_default_Arduino_GFX();
#else /* !defined(DISPLAY_DEV_KIT) */

/* More data bus class: https://github.com/moononournation/Arduino_GFX/wiki/Data-Bus-Class */
//Arduino_DataBus *bus = create_default_Arduino_DataBus();

/* More display class: https://github.com/moononournation/Arduino_GFX/wiki/Display-Class */
//Arduino_GFX *gfx = new Arduino_ILI9341(bus, DF_GFX_RST, 0 /* rotation */, false /* IPS */);


Arduino_ESP32RGBPanel *bus = new Arduino_ESP32RGBPanel(
    GFX_NOT_DEFINED /* CS */, GFX_NOT_DEFINED /* SCK */, GFX_NOT_DEFINED /* SDA */,
    41 /* DE */, 40 /* VSYNC */, 39 /* HSYNC */, 42 /* PCLK */,
    14 /* R0 */, 21 /* R1 */, 47 /* R2 */, 48 /* R3 */, 45 /* R4 */,
    9 /* G0 */, 46 /* G1 */, 3 /* G2 */, 8 /* G3 */, 16 /* G4 */, 1 /* G5 */,
    15 /* B0 */, 7 /* B1 */, 6 /* B2 */, 5 /* B3 */, 4 /* B4 */
);
// option 1:
// 7寸 50PIN 800*480
Arduino_RPi_DPI_RGBPanel *gfx = new Arduino_RPi_DPI_RGBPanel(
  bus,
//  800 /* width */, 0 /* hsync_polarity */, 8/* hsync_front_porch */, 2 /* hsync_pulse_width */, 43/* hsync_back_porch */,
//  480 /* height */, 0 /* vsync_polarity */, 8 /* vsync_front_porch */, 2/* vsync_pulse_width */, 12 /* vsync_back_porch */,
//  1 /* pclk_active_neg */, 16000000 /* prefer_speed */, true /* auto_flush */);

    800 /* width */, 0 /* hsync_polarity */, 210 /* hsync_front_porch */, 30 /* hsync_pulse_width */, 16 /* hsync_back_porch */,
    480 /* height */, 0 /* vsync_polarity */, 22 /* vsync_front_porch */, 13 /* vsync_pulse_width */, 10 /* vsync_back_porch */,
    1 /* pclk_active_neg */, 16000000 /* prefer_speed */, true /* auto_flush */);

#endif /* !defined(DISPLAY_DEV_KIT) */
/*******************************************************************************
 * End of Arduino_GFX setting
 ******************************************************************************/

/*******************************************************************************
 * Please config the touch panel in touch.h
 ******************************************************************************/
#include "touch.h"

/* Change to your screen resolution */
static uint32_t screenWidth = 800;
static uint32_t screenHeight = 480;
static lv_disp_draw_buf_t draw_buf;
static lv_color_t *disp_draw_buf;
static lv_disp_drv_t disp_drv;

/* Display flushing */
void my_disp_flush(lv_disp_drv_t *disp, const lv_area_t *area, lv_color_t *color_p)
{
  uint32_t w = (area->x2 - area->x1 + 1);
  uint32_t h = (area->y2 - area->y1 + 1);

#if (LV_COLOR_16_SWAP != 0)
  gfx->draw16bitBeRGBBitmap(area->x1, area->y1, (uint16_t *)&color_p->full, w, h);
#else
  gfx->draw16bitRGBBitmap(area->x1, area->y1, (uint16_t *)&color_p->full, w, h);
#endif

  lv_disp_flush_ready(disp);
}

void my_touchpad_read(lv_indev_drv_t *indev_driver, lv_indev_data_t *data)
{
  if (touch_has_signal())
  {
    if (touch_touched())
    {
      data->state = LV_INDEV_STATE_PR;

      /*Set the coordinates*/
      data->point.x = touch_last_x;
      data->point.y = touch_last_y;
    // Serial.print( "Data x " );
   //  Serial.println( data->point.x );
     // Serial.print( "Data y " );
     // Serial.println( data->point.y );
    }
    else if (touch_released())
    {
      data->state = LV_INDEV_STATE_REL;
    }
  }
  else
  {
    data->state = LV_INDEV_STATE_REL;
  }
}

int GRID = 0;
int SOLAR = 0;
int TOTAL =0;

void setup()
{
  Serial.begin(115200);
  SerialPort.begin(115200, SERIAL_8N1, 17, 18);
  // while (!Serial);
  delay(10);

   
  Serial.println("LVGL Widgets Demo");
  // Init Display
  gfx->begin();
#ifdef TFT_BL
  pinMode(TFT_BL, OUTPUT);
  digitalWrite(TFT_BL, HIGH);
Serial.println("screen");
  ledcSetup(0, 300, 8);
  ledcAttachPin(TFT_BL, 0);
  ledcWrite(0, 20); /* Screen brightness can be modified by adjusting this parameter. (0-255) */
Serial.println("led");  
#endif
  //gfx->fillScreen(RED);
 // delay(500);
  //gfx->fillScreen(GREEN);
  delay(500);
  gfx->fillScreen(BLUE);
  delay(500);
  gfx->fillScreen(BLACK);
  delay(500);
  lv_init();

    // Init touch device
  pinMode(TOUCH_GT911_RST, OUTPUT);
  digitalWrite(TOUCH_GT911_RST, LOW);
  delay(10);
  digitalWrite(TOUCH_GT911_RST, HIGH);
  delay(10);
 Serial.println("touch"); 
  touch_init();
//  touch.setTouch( calData );
 Serial.println("fin"); 
  screenWidth = gfx->width();
  screenHeight = gfx->height();
#ifdef ESP32
  disp_draw_buf = (lv_color_t *)heap_caps_malloc(sizeof(lv_color_t) * screenWidth *screenHeight/4  , MALLOC_CAP_INTERNAL | MALLOC_CAP_8BIT);
#else
  disp_draw_buf = (lv_color_t *)malloc(sizeof(lv_color_t) * screenWidth *screenHeight/4);
#endif
  if (!disp_draw_buf)
  {
    Serial.println("LVGL disp_draw_buf allocate failed!");
  }
  else
  {
    lv_disp_draw_buf_init(&draw_buf, disp_draw_buf, NULL, screenWidth *screenHeight/4);

    /* Initialize the display */
    lv_disp_drv_init(&disp_drv);
    /* Change the following line to your display resolution */
    disp_drv.hor_res = screenWidth;
    disp_drv.ver_res = screenHeight;
    disp_drv.flush_cb = my_disp_flush;
    disp_drv.draw_buf = &draw_buf;
    lv_disp_drv_register(&disp_drv);

    /* Initialize the (dummy) input device driver */
    static lv_indev_drv_t indev_drv;
    lv_indev_drv_init(&indev_drv);
    indev_drv.type = LV_INDEV_TYPE_POINTER;
    indev_drv.read_cb = my_touchpad_read;
    lv_indev_drv_register(&indev_drv);
 Serial.println("ui stated"); 
    ui_init();

    Serial.println("Setup done");
  }

    

}

//////////////
String command;
void loop()
{
  lv_timer_handler(); /* let the GUI do its work */
  delay(5);
   
 if(SerialPort.available())
   {
      char c = SerialPort.read();
    
      if (c == ')')
      {
       
        parseCommand(command);
        
        command="";
      }
      else
      {
       command += c;
      }
  }
    


}


void parseCommand(String com)
{
if (command == "hello"){
  Serial.println("seen");
}
//--com variables  
char test[5];
  String part1;
  String part2;
  
  part1 = com.substring(6, com.indexOf("("));
  //int test = part1.toInt();
 // Serial.print(part1);
  //Serial.println("#");
  part2 = com.substring(com.indexOf("(")+1);
  //Serial.println(part2);

//--input 
//////////////////////  

  if (part1 == "1")
  {
     float tmpC  = part2.toFloat(); 
  int  reading = (tmpC + 0.5);
 
      char buf[4]; // sprintf text buffer
  sprintf(buf, "%2d", reading);
  Serial.println(buf);
  lv_label_set_text(ui_Labelhumidex, buf); 
  
    }
  if (part1== "2")
    {
      //Serial.println(part2);
 float tmpC  = part2.toFloat(); 
  int  reading = (tmpC + 40.5);
 //Serial.println(reading);
    lv_arc_set_value(ui_Arc1, reading);
    reading = (tmpC + 0.5);
      char buf[4]; // sprintf text buffer
  sprintf(buf, "%2d", reading);
  Serial.println(buf);
  lv_label_set_text(ui_Label_Temp, buf); 
  }

 if (part1 == "3")
    {
     // Serial.println(part2);
  float tmpC  = part2.toFloat(); 
  int  reading = (tmpC + 0.5);
 
      char buf[4]; // sprintf text buffer
  sprintf(buf, "%2d", reading);
  Serial.println(buf);
  lv_label_set_text(ui_Labelwindc, buf); 

  }

  if (part1 == "4")
  {
     int  reading = (part2.toInt());
 Serial.println(reading);
 SOLAR = reading;
    lv_bar_set_value(ui_Bar3, reading, LV_ANIM_OFF);
      char buf[4]; // sprintf text buffer
  sprintf(buf, "%2d", reading);
  //Serial.println(buf);
  lv_label_set_text(ui_Label_Solar, buf);


       }
  if (part1== "5")
    {
     // Serial.println(part2);
 int  reading = (part2.toInt());
 //Serial.println(reading);
 GRID = reading;
 TOTAL = GRID + SOLAR;
 lv_bar_set_value(ui_Bar1, TOTAL, LV_ANIM_OFF);
  lv_bar_set_value(ui_Bar2, reading, LV_ANIM_OFF);
  char buf[4]; // sprintf text buffer
  sprintf(buf, "%2d", reading);
  Serial.println(buf);
  lv_label_set_text(ui_Label_Grid, buf);
  sprintf(buf, "%2d", TOTAL);
  //Serial.println(buf);
  lv_label_set_text(ui_Label_Total, buf);

    }

    if (part1== "6")
    {
      //Serial.println(part2);
 int  reading = (part2.toInt());
 //Serial.println(reading);
    lv_bar_set_value(ui_Bar4, reading, LV_ANIM_OFF);
      char buf[4]; // sprintf text buffer
  sprintf(buf, "%2d", reading);
  Serial.println(buf);
  lv_label_set_text(ui_Label_DIV, buf);
 
    }
    
    if (part1== "7")
    {
      ///number example INT round up//////
      //Serial.println(part2);
      float tmpC  = part2.toFloat(); 
      int  reading = (tmpC + 0.5);
      char buf[4]; // sprintf text buffer
      sprintf(buf, "%2d", reading);
      Serial.println(buf);
      lv_label_set_text(ui_Labelwinds, buf); 
    }
    if (part1== "8")
    { 
    /////text/////// 
   int part2_len = part2.length() + 1;  
   char buf[part2_len];
   part2.toCharArray(buf, part2_len);    
   Serial.println(buf);
   lv_label_set_text(ui_LabelDATE, buf);
   lv_label_set_text(ui_LabelDATE1, buf);
   lv_label_set_text(ui_LabelDATE2, buf); 
   lv_label_set_text(ui_LabelDATE3, buf);   
    }

    if (part1== "9")
    {
      int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_LabelTIME, buf);
      lv_label_set_text(ui_LabelTIME1, buf);
      lv_label_set_text(ui_LabelTIME2, buf);
      lv_label_set_text(ui_LabelTIME3, buf);
      
    }
/////////////////
    if (part1== "10")
    {
      if (part2 == "clear"){
        Serial.println("clearing TxB");
      AIDATA = "0";
      lv_textarea_set_text(ui_TextAreaAI, "");
      
      // ai/onlight/off   can be use   it to denote ai speech 1/0  but  buta strings can be sent  other  single character 1 or 0
    }
    }

        if (part1== "11")
    {
      // ai/onlight/off   can be use   it to denote ai speech 1/0  but  buta strings can be sent  other  single character 1 or 0
    }

        if (part1== "12")
    {
            int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_INFOBOX0, buf);
    }

        if (part1== "13")
    {
      int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_INFOBOX, buf);
    }

        if (part1== "14")
    {
            int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_INFOBOX2, buf);
    }

        if (part1== "15")
    {
      lv_label_set_text(ui_INFOBOX, ""); 
      lv_label_set_text(ui_INFOBOX2, "");
      lv_label_set_text(ui_INFOBOX0, "");
      // clear info box 
    }

        if (part1== "16")
    {
      if (AIDATA == "##@%%") {
        Serial.println("starting TxB");
            int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_textarea_set_text(ui_TextAreaAI, buf);
      AIDATA = "1";
      }
      else{
        Serial.println("adding to TxB");
        lv_textarea_add_text(ui_TextAreaAI, "\n"); // line break
                   int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_textarea_add_text(ui_TextAreaAI, buf); 
      }
    }
///////////////weather & forecast
        if (part1== "17")
    {
            int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_LabelWDescip, buf);
    }

        if (part1== "18")
    {
            int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_LabelTHigh, buf);
    }

        if (part1== "19")
    {
            int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_LabelTLow, buf);
    }

        if (part1== "20")
    {
            int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_LabelFDescip, buf);
    }

        if (part1== "21")
    {
            int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_LabelTHighF, buf);
    }

        if (part1== "22")
    {
            int part2_len = part2.length() + 1;  
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_LabelTLowF, buf);
    }
///////////////////////  evacuated solar tubes
        if (part1== "23")
    {

    }

        if (part1== "24")
    {

    }

        if (part1== "25")
    {

    }

        if (part1== "26")
    {

    }

        if (part1== "27")
    {

    }

        if (part1== "28")
    {

    }
/////////////////////////// energy section solar /wind 
        if (part1== "29")
    {
            ///number example INT round up//////
      //Serial.println(part2);
      float tmpC  = part2.toFloat(); 
      int  reading = (tmpC + 0.5);
      char buf[4]; // sprintf text buffer
      sprintf(buf, "%2d", reading);
      Serial.println(buf);
      lv_label_set_text(ui_SolarP1, buf); 
    }

        if (part1== "30")
    {
            ///number example INT round up//////
      //Serial.println(part2);
      float tmpC  = part2.toFloat(); 
      int  reading = (tmpC + 0.5);
      char buf[4]; // sprintf text buffer
      sprintf(buf, "%2d", reading);
      Serial.println(buf);
      lv_label_set_text(ui_SolarP2, buf); 
    }

        if (part1== "31")
    {
            ///number example INT round up//////
      //Serial.println(part2);
      float tmpC  = part2.toFloat(); 
      int  reading = (tmpC + 0.5);
      char buf[4]; // sprintf text buffer
      sprintf(buf, "%2d", reading);
      Serial.println(buf);
      lv_label_set_text(ui_SolarP3, buf); 
    }

        if (part1== "32")
    {
            ///number example INT round up//////
      //Serial.println(part2);
      float tmpC  = part2.toFloat(); 
      int  reading = (tmpC + 0.5);
      char buf[4]; // sprintf text buffer
      sprintf(buf, "%2d", reading);
      Serial.println(buf);
      lv_label_set_text(ui_SolarP4, buf); 
    }

        if (part1== "33")
    {
            ///number example INT round up//////
      //Serial.println(part2);
      float tmpC  = part2.toFloat(); 
      int  reading = (tmpC + 0.5);
      char buf[4]; // sprintf text buffer
      sprintf(buf, "%2d", reading);
      Serial.println(buf);
      lv_label_set_text(ui_SolarP5, buf); 
    }

        if (part1== "34")
    {
      
    }

        if (part1== "35")
    {
      
    }

        if (part1== "36")
    {

    }
///////////// battery
        if (part1== "37")
    {
           int  reading = (part2.toInt());
           Serial.println(reading);
           //SOLAR = reading;
           lv_bar_set_value(ui_BatteryLev, reading, LV_ANIM_OFF);
           char buf[4]; // sprintf text buffer
           sprintf(buf, "%2d", reading);
           //Serial.println(buf);
           lv_label_set_text(ui_BaterySoC, buf);
    }

        if (part1== "38")
    {
      int part2_len = part2.length() + 1;  ///battery temp
      char buf[part2_len];
      part2.toCharArray(buf, part2_len); 
      Serial.println(buf);
      lv_label_set_text(ui_Label61, buf);   ///battery temp
    }

        if (part1== "39")
    {

    }

        if (part1== "40")
    {
 
    }

        if (part1== "41")
    {

    }

        if (part1== "42")
    {

    }
///////////////////////
        if (part1== "43")
    {
      
    }

        if (part1== "44")
    {
      
    }

        if (part1== "45")
    {
      
    }

        if (part1== "46")
    {
      
    }

        if (part1== "47")
    {
      
    }

        if (part1== "48")
    {
      
    }

        if (part1== "49")
    {
      
    }

        if (part1== "50")
    {
      
    }

    
    
}


///////////////////////////
///////////////////////////
void playradio(lv_event_t * e)
{
  // Your code here 
 SerialPort.write("cmd_100(1) ");
 Serial.println("radio");
}

void stopplayback(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(0) ");
 Serial.println("stop_plaback");
}

void aiplayback(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(2) ");
 Serial.println("Start ai");
}

void upperswitchon(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(4) ");
 Serial.println("Aux switch1 on");
}

void upperswitchoff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(3) ");
 Serial.println("Aux switch1 off");
}

void lowerswitchon(lv_event_t * e)
{
  // Your code here
    SerialPort.write("cmd_100(6) ");
 Serial.println("Aux switch2 on");
}

void lowerswitchoff(lv_event_t * e)
{
  // Your code here
    SerialPort.write("cmd_100(5) ");
 Serial.println("Aux switch1 off");
}

void Playkiss(lv_event_t * e)
{
    SerialPort.write("cmd_100(7) ");
 Serial.println("kiss fm");
}

void Playpeggy(lv_event_t * e)
{
  // Your code here
    SerialPort.write("cmd_100(8) ");
 Serial.println("Peggy fm");
}

void Playcity(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(9) ");
 Serial.println("city fm");
}

void Playvirgin(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(10) ");
 Serial.println("virgin fm");
}

void Playpower(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(11) ");
 Serial.println("power97 fm");
}

void Playcjob(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(12) ");
 Serial.println("cjob");
}

void Playtsnr(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(13) ");
 Serial.println("TSN");
}

void Playberlin(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(14) ");
 Serial.println("Berlin radio");
}

void Playmusic(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(15) ");
 Serial.println("Music folder");
}

void Playweather(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(16) ");
 Serial.println("weather");
}

void Playforecast(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(17) ");
 Serial.println("weather forecast");
}

void PlayAlert(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(18) ");
 Serial.println("weather alerts");
}

void Playscifi(lv_event_t * e)
{
  // Your code here
      SerialPort.write("cmd_100(19) ");
 Serial.println("book-SciFi");
}

void Playoffice(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(20) ");
 Serial.println("playback-office");
}

void Playhorror(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(21) ");
 Serial.println("book-horror");
}

void Playcrime(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(22) ");
 Serial.println("book-crime");
}

void Playrandom(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(23) ");
 Serial.println("book-random");
}

void Playlivingroom(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(24) ");
 Serial.println("playback-livingroom");
}

void Playoutside(lv_event_t * e)
{
  // Your code here
    SerialPort.write("cmd_100(25) ");
 Serial.println("playback-outside");
}

void Playallloc(lv_event_t * e)
{
  // Your code here
    SerialPort.write("cmd_100(26) ");
 Serial.println("playback-all locations");
}

void LivingRoomPoN(lv_event_t * e)
{
  // Your code here
    SerialPort.write("cmd_100(28) ");
 Serial.println("livingroom outlet on");
}

void LivingRoomPoff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(27) ");
 Serial.println("livingroom outlet off");
}

void BathroonPon(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(30) ");
 Serial.println("bathroom outlet on");
  
}

void BathroomPoff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(29) ");
 Serial.println("bathroom outlet off");
}

void BedRoom1Pon(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(32) ");
 Serial.println("bedgroom 1 outlet on");
}

void Bedroom1Poff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(31) ");
 Serial.println("bedroom 1 outlet off");
}

void Bedroom2Pon(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(34) ");
 Serial.println("bedroom 2 outlet on");
}

void Bedroom2Poff(lv_event_t * e)
{
  // Your code here
    SerialPort.write("cmd_100(33) ");
 Serial.println("bedroom 2 outlet off");
}

void OfficePlugon(lv_event_t * e)
{
  // Your code here
    SerialPort.write("cmd_100(36) ");
 Serial.println("office outlet on");
}

void OfficePlugoff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(35) ");
 Serial.println("office outlet off");
}

void MiscPlugon(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(38) ");
 Serial.println("misc outlet on");
}

void MiscPlugoff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(37) ");
 Serial.println("misc outlet off");
}

void LivingroomLon(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(40) ");
 Serial.println("livingroom lights on");
}

void LivingroomLoff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(39) ");
 Serial.println("livingroom lights off");
}

void BathroomLon(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(42) ");
 Serial.println("bathroom lights on");
}

void BathroomLoff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(41) ");
 Serial.println("bathroom lights off");
}

void BedRoom1lon(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(44) ");
 Serial.println("bedroom 1 lights on");
}

void Bedroom2Lon(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(46) ");
 Serial.println("bedroom 2 lights on");
}

void Bedroom2Loff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(45) ");
 Serial.println("bedroom 2 lights off");
}

void OfficeLightson(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(48) ");
 Serial.println("office lights on");
}

void OfficeLightoff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(47) ");
 Serial.println("office lights off");
}

void MiscLightson(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(50) ");
 Serial.println("misc lights on");
}

void Misclightsoff(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(49) ");
 Serial.println("misc lights off");
}

void BedRoom1off(lv_event_t * e)
{
  // Your code here
  SerialPort.write("cmd_100(43) ");
 Serial.println("bedroom 1 lights off");
}
